ButtonThemeData class

Theme data for button widgets.

This class defines the default styles for different button types in the Fluent UI design system.

Mixed-in types
Annotations

Constructors

ButtonThemeData({ButtonStyle? defaultButtonStyle, ButtonStyle? filledButtonStyle, ButtonStyle? hyperlinkButtonStyle, ButtonStyle? outlinedButtonStyle, ButtonStyle? iconButtonStyle})
Creates button theme data with optional styles for each button type.
const
ButtonThemeData.all(ButtonStyle? style)
Creates button theme data with the same style for all button types.
const

Properties

defaultButtonStyle ButtonStyle?
The style for default Button widgets.
final
filledButtonStyle ButtonStyle?
The style for FilledButton widgets.
final
hashCode int
The hash code for this object.
no setterinherited
hyperlinkButtonStyle ButtonStyle?
The style for HyperlinkButton widgets.
final
iconButtonStyle ButtonStyle?
The style for IconButton widgets.
final
outlinedButtonStyle ButtonStyle?
The style for outlined button widgets.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ButtonThemeData? style) ButtonThemeData
Merges this ButtonThemeData with another, with the other taking precedence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buttonColor(BuildContext context, Set<WidgetState> states, {bool transparentWhenNone = false}) Color
Defines the default color used by Buttons using the current brightness and state.
buttonForegroundColor(BuildContext context, Set<WidgetState> states) Color
Defines the default foregournd color used by Buttons using the current brightness and state.
checkedInputColor(FluentThemeData theme, Set<WidgetState> states) Color
Defines the default color used for inputs when checked, such as checkbox, radio button and toggle switch. It's based on the current style and the current state.
lerp(ButtonThemeData? a, ButtonThemeData? b, double t) ButtonThemeData
Linearly interpolates between two ButtonThemeData objects.
shapeBorder(BuildContext context, Set<WidgetState> states) ShapeBorder
Returns the default shape border for buttons based on the current state.
uncheckedInputColor(FluentThemeData theme, Set<WidgetState> states, {bool transparentWhenNone = false, bool transparentWhenDisabled = false}) Color
Defines the default color used for unchecked inputs, such as checkbox, radio button and toggle switch, based on the current state.