FilledButton class

An accent-colored button used for primary or most important actions.

The FilledButton has a filled background using the app's accent color, making it stand out as the primary action in a dialog or page. Use this button for the most important action you want users to take.

FilledButton Example

{@tool snippet} This example shows a filled button used as a primary action:

FilledButton(
  child: Text('Save'),
  onPressed: () => saveDocument(),
)

{@end-tool}

{@tool snippet} This example shows a dialog with a filled button as the primary action:

ContentDialog(
  title: Text('Save changes?'),
  content: Text('Do you want to save your changes before closing?'),
  actions: [
    Button(
      child: Text('Cancel'),
      onPressed: () => Navigator.pop(context),
    ),
    FilledButton(
      child: Text('Save'),
      onPressed: () {
        saveChanges();
        Navigator.pop(context);
      },
    ),
  ],
)

{@end-tool}

See also:

Inheritance

Constructors

FilledButton({required Widget child, required GestureTapCallback? onPressed, Key? key, GestureLongPressCallback? onLongPress, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, FocusNode? focusNode, bool autofocus = false, ButtonStyle? style, bool focusable = true})
Creates a filled button.
const

Properties

autofocus bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
child Widget
Typically the button's label.
finalinherited
enabled bool
Whether the button is enabled or disabled.
no setterinherited
focusable bool
Whether this button can be focused.
finalinherited
focusNode FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onLongPress GestureLongPressCallback?
Called when the button is long-pressed.
finalinherited
onPressed GestureLongPressCallback?
Called when the button is tapped or otherwise activated.
finalinherited
onTapDown GestureTapDownCallback?
Called when the button is pressed.
finalinherited
onTapUp GestureTapUpCallback?
Called when the button is released.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style ButtonStyle?
Customizes this button's appearance.
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BaseButton>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultStyleOf(BuildContext context) ButtonStyle
Returns the default style for this button type based on the context.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
themeStyleOf(BuildContext context) ButtonStyle?
Returns the theme style for this button type, if defined.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

backgroundColor(FluentThemeData theme, Set<WidgetState> states) Color
Returns the background color for a filled button based on its state.
foregroundColor(FluentThemeData theme, Set<WidgetState> states) Color
Returns the foreground color for a filled button based on its state.
shapeBorder(FluentThemeData theme, Set<WidgetState> states) ShapeBorder
Returns the shape border for a filled button based on its state.