FocusThemeData class

Theme data for FocusBorder widgets.

Mixed-in types

Constructors

FocusThemeData({BorderRadius? borderRadius, BorderSide? primaryBorder, BorderSide? secondaryBorder, Color? glowColor, double? glowFactor, bool? renderOutside})
Creates a theme data for FocusBorder widgets.
const
FocusThemeData.standard(FluentThemeData theme)
Creates the standard FocusThemeData based on the given theme.
factory

Properties

borderRadius BorderRadius?
The border radius of the focus border.
final
glowColor Color?
The glow color of the focus border.
final
glowFactor double?
The glow factor of the focus border.
final
hashCode int
The hash code for this object.
no setterinherited
primaryBorder BorderSide?
The primary border of the focus border.
final
renderOutside bool?
Whether the focus border should be rendered outside of the box or not.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryBorder BorderSide?
The secondary border of the focus border.
final

Methods

buildPrimaryDecoration(bool focused) Decoration
Builds the primary decoration for the focus border.
buildSecondaryDecoration(bool focused) Decoration
Builds the secondary decoration for the focus border.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(FocusThemeData? other) FocusThemeData
Merges this FocusThemeData with another, with the other taking precedence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

lerp(FocusThemeData? a, FocusThemeData? b, double t) FocusThemeData
Lerps between two FocusThemeData objects.