IconButtonMode enum

The size mode for an IconButton.

This determines the overall size and padding of the icon button.

Inheritance
Available extensions

Values

tiny → const IconButtonMode

A very small icon button, typically used in compact UI areas.

small → const IconButtonMode

A small icon button, suitable for toolbars and dense layouts.

large → const IconButtonMode

A large icon button with more padding, the default size.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IconButtonMode>
A constant List of the values in this enum, in order of their declaration.