InfoLabel class

An info label lets the user know what an element of the ui do as a short description of its functionality. It can be either rendered above its child or on the side of it.

InfoLabel above a TextBox

Inheritance

Constructors

InfoLabel({Key? key, Widget? child, required String label, TextStyle? labelStyle, bool isHeader = true})
Creates an info label.
const

Properties

child → Widget?
The widget to apply the label.
final
hashCode → int
The hash code for this object.
no setterinherited
isHeader → bool
Whether to render header above child or on the side of it.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
The text of the label. It'll be styled acorrding to headerStyle. If this is empty, a blank space will be rendered.
final
labelStyle → TextStyle?
The style of the text. If null, Typography.body is used
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited