MenuBar class
Use a Menu Bar to show a set of multiple top-level menus in a horizontal row.

See also:
- learn.microsoft.com/en-us/windows/apps/design/controls/menus#create-a-menu-bar
- bdlukaa.github.io/fluent_ui/#/popups/menu_bar
- MenuBarItem, the items used in this menu bar
- MenuFlyout, a popup that shows a list of items
- CommandBar, a toolbar that provides a customizable layout for commands
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MenuBar
- Mixed-in types
Constructors
-
MenuBar({required List<
MenuBarItem> items, Key? key}) - Creates a windows-styled menu bar.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
MenuBarItem> -
The items to display in the menu bar.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MenuBar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited