header property
The header of the pane.
If null, the space it should have taken will be removed from the pane (PaneDisplayMode.minimal and PaneDisplayMode.expanded only).
Usually a Text, Image or Icon.

Implementation
final Widget? header;
The header of the pane.
If null, the space it should have taken will be removed from the pane (PaneDisplayMode.minimal and PaneDisplayMode.expanded only).
Usually a Text, Image or Icon.

final Widget? header;