NavigationPanelItem class

Implementers

Constructors

const

Properties

hashCode → int
The hash code for this object.
no setterinherited
final
icon → Widget?
The icon of the item. Usually an Icon widget
final
label → Widget?
The label of the item. Usually a Text widget
final
onTapped → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → NavigationPanelThemeData?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited