NavigationViewState class
- Inheritance
-
- Object
- State<
NavigationView> - NavigationViewState
Constructors
Properties
- compactOverlayOpen ↔ bool
-
Whether the compact pane is open.
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- displayMode → PaneDisplayMode
-
The current display mode.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTitleBar → bool
-
Whether the navigation view has a title bar.
no setter
- isMinimalPaneOpen ↔ bool
-
Whether the minimal pane is open.
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- paneScrollController → ScrollController
-
The scroll controller used to keep the scrolling state of the list view
when the display mode is switched between open and compact, and even keep
it for the minimal state.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toggleButtonPosition → PaneToggleButtonPosition
-
The position of the toggle pane button.
no setter
- widget → NavigationView
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Builds the navigation view with adaptive layout based on display mode.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant NavigationView oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
ensureSelectedItemVisible(
{Duration? duration, Curve? curve}) → void - Ensures the current selected item is visible in the pane.
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop(
) → void - Pops the current item from the history.
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleCompactOpenMode(
) → void - Toggles the compact open mode.
-
toggleMinimalPane(
) → void - Toggles the minimal pane open mode.
-
togglePane(
) → void - Toggles the current pane.
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited