ProgressRing class
A circular progress indicator that shows operation progress.
Progress rings provide visual feedback about ongoing operations in a compact, circular format. They're especially useful when horizontal space is limited or when you need a loading indicator.
The progress ring can operate in two modes:
- Determinate - Shows specific progress from 0-100%. Use when you can measure the operation's progress.

- Indeterminate - Shows a spinning animation. Use when the operation duration is unknown.

{@tool snippet} This example shows an indeterminate progress ring:
ProgressRing()
{@end-tool}
{@tool snippet} This example shows a determinate progress ring:
ProgressRing(value: 65)
{@end-tool}
See also:
- ProgressBar, a linear progress indicator
- learn.microsoft.com/en-us/windows/apps/design/controls/progress-controls
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ProgressRing
Constructors
Properties
- activeColor → Color?
-
The active color of the progress ring.
final
- backgroundColor → Color?
-
The background color of the progress ring.
final
- backwards → bool
-
Whether the indicator spins backwards or not. Defaults to false
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
Semantic label for the input.
final
- strokeWidth → double
-
The stroke width of the progress ring.
final
- value → double?
-
The current value of the indicator. This value must be between 0 and 100.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ProgressRing> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited