RadioButtonThemeData class

Mixed-in types
Annotations

Constructors

RadioButtonThemeData({ButtonState<MouseCursor>? cursor, Duration? animationDuration, Curve? animationCurve, ButtonState<BoxDecoration>? checkedDecoration, ButtonState<BoxDecoration>? uncheckedDecoration})
const
RadioButtonThemeData.standard(ThemeData style)
factory

Properties

animationCurve → Curve?
final
animationDuration → Duration?
final
checkedDecoration → ButtonState<BoxDecoration>?
final
cursor → ButtonState<MouseCursor>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uncheckedDecoration → ButtonState<BoxDecoration>?
final

Methods

copyWith(RadioButtonThemeData? style) → RadioButtonThemeData
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited