TabView class
A tabbed interface for displaying multiple pages of content.
TabView provides a familiar tab-based navigation pattern, similar to browser tabs. Users can switch between tabs, and optionally rearrange, open, or close tabs.

{@tool snippet} This example shows a basic tab view:
TabView(
currentIndex: selectedIndex,
onChanged: (index) => setState(() => selectedIndex = index),
tabs: [
Tab(
text: Text('Document 1'),
body: Center(child: Text('Content 1')),
),
Tab(
text: Text('Document 2'),
body: Center(child: Text('Content 2')),
),
],
onNewPressed: () {
// Add a new tab
},
)
{@end-tool}