TimePicker class

The time picker gives you a standardized way to let users pick a time value using touch, mouse, or keyboard input. Use a time picker to let a user pick a single time value.

TimePicker Preview7

See also:

Inheritance

Constructors

TimePicker({Key? key, required DateTime? selected, ValueChanged<DateTime>? onChanged, VoidCallback? onCancel, String? header, TextStyle? headerStyle, EdgeInsetsGeometry contentPadding = kPickerContentPadding, double popupHeight = kPopupHeight, MouseCursor cursor = SystemMouseCursors.click, FocusNode? focusNode, bool autofocus = false, HourFormat hourFormat = HourFormat.h, String hourPlaceholder = 'hour', String minutePlaceholder = 'minute', String amText = 'AM', String pmText = 'PM', double minuteIncrement = 1})
const

Properties

amText → String
final
autofocus → bool
final
contentPadding → EdgeInsetsGeometry
final
cursor → MouseCursor
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
final
headerStyle → TextStyle?
final
hourFormat → HourFormat
final
hourPlaceholder → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minuteIncrement → double
final
minutePlaceholder → String
final
onCancel → VoidCallback?
final
onChanged → ValueChanged<DateTime>?
final
pmText → String
final
popupHeight → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → DateTime?
final
use24Format → bool
no setter

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TimePickerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited