WindowsTextSelectionToolbar class
A Windows-styled text selection toolbar.
This toolbar appears when text is selected in a TextBox or EditableText, providing options like cut, copy, paste, and select all.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- WindowsTextSelectionToolbar
Constructors
-
WindowsTextSelectionToolbar({required List<
ContextMenuButtonItem> buttonItems, required TextSelectionToolbarAnchors anchors, Key? key}) -
Creates a Fluent text selection toolbar.
const
- WindowsTextSelectionToolbar.editableText({required EditableTextState editableTextState, Key? key})
- Create an instance of WindowsTextSelectionToolbar with the default children for an EditableText.
Properties
- anchors → TextSelectionToolbarAnchors
-
The location on which to anchor the menu.
final
-
- AdaptiveTextSelectionToolbar.buttonItems, which takes a list of
ContextMenuButtonItems instead ofchildrenwidgets.final - AdaptiveTextSelectionToolbar.buttonItems, which takes a list of
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
contextMenuTypeToIcon(
ContextMenuButtonType type) → IconData? - Returns the icon for a context menu button type.
-
contextMenuTypeToLabel(
ContextMenuButtonType type, BuildContext context) → String? - Returns the localized label for a context menu button type.
-
contextMenuTypeToShortcut(
ContextMenuButtonType type, BuildContext context) → String? - Returns the keyboard shortcut text for a context menu button type.
-
contextMenuTypeToTooltip(
ContextMenuButtonType type, BuildContext context) → String? - Returns the localized tooltip for a context menu button type.
-
defaultContextMenuBuilder(
BuildContext context, EditableTextState editableTextState) → Widget - The default context menu builder for TextBox.