FluentLocalizationsFr class

The translations for French (fr).

Inheritance
Available extensions

Constructors

FluentLocalizationsFr([String locale = 'fr'])

Properties

am → String
The text used by TimePicker for the AM field.
no setteroverride
backButtonTooltip → String
The tooltip for the back button on NavigationAppBar.
no setteroverride
blueLabel → String
Label for blue color component in color picker
no setteroverride
clickToSearch → String
The tooltip for the "Click to Search" button.
no setteroverride
closeButtonLabel → String
Label for "close" buttons and menu items.
no setteroverride
closeNavigationTooltip → String
The tooltip for the toggle navigation button.
no setteroverride
closeTabLabel → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

The label used by TabView's close button.
no setter
closeTabLabelSuffix → String
The label used by TabView's close button.
no setteroverride
closeWindowTooltip → String
The tooltip used by the "Close" button on desktop windows.
no setteroverride
colorAliceBlue → String
The name of the color, Alice Blue.
no setteroverride
colorAntiqueWhite → String
The name of the color, Antique White.
no setteroverride
colorAquamarine → String
The name of the color, Aquamarine.
no setteroverride
colorAzure → String
The name of the color, Azure.
no setteroverride
colorBeige → String
The name of the color, Beige.
no setteroverride
colorBisque → String
The name of the color, Bisque.
no setteroverride
colorBlack → String
The name of the color, Black.
no setteroverride
colorBlanchedAlmond → String
The name of the color, Blanched Almond.
no setteroverride
colorBlue → String
The name of the color, Blue.
no setteroverride
colorBlueViolet → String
The name of the color, Blue Violet.
no setteroverride
colorBrown → String
The name of the color, Brown.
no setteroverride
colorBurlyWood → String
The name of the color, Burly Wood.
no setteroverride
colorCadetBlue → String
The name of the color, Cadet Blue.
no setteroverride
colorChartreuse → String
The name of the color, Chartreuse.
no setteroverride
colorChocolate → String
The name of the color, Chocolate.
no setteroverride
colorCoral → String
The name of the color, Coral.
no setteroverride
colorCornflowerBlue → String
The name of the color, Cornflower Blue.
no setteroverride
colorCornsilk → String
The name of the color, Cornsilk.
no setteroverride
colorCrimson → String
The name of the color, Crimson.
no setteroverride
colorCyan → String
The name of the color, Cyan.
no setteroverride
colorDarkBlue → String
The name of the color, Dark Blue.
no setteroverride
colorDarkCyan → String
The name of the color, Dark Cyan.
no setteroverride
colorDarkGoldenrod → String
The name of the color, Dark Goldenrod.
no setteroverride
colorDarkGray → String
The name of the color, Dark Gray.
no setteroverride
colorDarkGreen → String
The name of the color, Dark Green.
no setteroverride
colorDarkKhaki → String
The name of the color, Dark Khaki.
no setteroverride
colorDarkMagenta → String
The name of the color, Dark Magenta.
no setteroverride
colorDarkOliveGreen → String
The name of the color, Dark Olive Green.
no setteroverride
colorDarkOrange → String
The name of the color, Dark Orange.
no setteroverride
colorDarkOrchid → String
The name of the color, Dark Orchid.
no setteroverride
colorDarkRed → String
The name of the color, Dark Red.
no setteroverride
colorDarkSalmon → String
The name of the color, Dark Salmon.
no setteroverride
colorDarkSeaGreen → String
The name of the color, Dark Sea Green.
no setteroverride
colorDarkSlateBlue → String
The name of the color, Dark Slate Blue.
no setteroverride
colorDarkSlateGray → String
The name of the color, Dark Slate Gray.
no setteroverride
colorDarkTurquoise → String
The name of the color, Dark Turquoise.
no setteroverride
colorDarkViolet → String
The name of the color, Dark Violet.
no setteroverride
colorDeepPink → String
The name of the color, Deep Pink.
no setteroverride
colorDeepSkyBlue → String
The name of the color, Deep Sky Blue.
no setteroverride
colorDimGray → String
The name of the color, Dim Gray.
no setteroverride
colorDodgerBlue → String
The name of the color, Dodger Blue.
no setteroverride
colorFirebrick → String
The name of the color, Firebrick.
no setteroverride
colorFloralWhite → String
The name of the color, Floral White.
no setteroverride
colorForestGreen → String
The name of the color, Forest Green.
no setteroverride
colorGainsboro → String
The name of the color, Gainsboro.
no setteroverride
colorGhostWhite → String
The name of the color, Ghost White.
no setteroverride
colorGold → String
The name of the color, Gold.
no setteroverride
colorGoldenrod → String
The name of the color, Goldenrod.
no setteroverride
colorGray → String
The name of the color, Gray.
no setteroverride
colorGreen → String
The name of the color, Green.
no setteroverride
colorGreenYellow → String
The name of the color, Green Yellow.
no setteroverride
colorHoneydew → String
The name of the color, Honeydew.
no setteroverride
colorHotPink → String
The name of the color, Hot Pink.
no setteroverride
colorIndianRed → String
The name of the color, Indian Red.
no setteroverride
colorIndigo → String
The name of the color, Indigo.
no setteroverride
colorIvory → String
The name of the color, Ivory.
no setteroverride
colorKhaki → String
The name of the color, Khaki.
no setteroverride
colorLavender → String
The name of the color, Lavender.
no setteroverride
colorLavenderBlush → String
The name of the color, Lavender Blush.
no setteroverride
colorLawnGreen → String
The name of the color, Lawn Green.
no setteroverride
colorLemonChiffon → String
The name of the color, Lemon Chiffon.
no setteroverride
colorLightBlue → String
The name of the color, Light Blue.
no setteroverride
colorLightCoral → String
The name of the color, Light Coral.
no setteroverride
colorLightCyan → String
The name of the color, Light Cyan.
no setteroverride
colorLightGoldenrodYellow → String
The name of the color, Light Goldenrod Yellow.
no setteroverride
colorLightGray → String
The name of the color, Light Gray.
no setteroverride
colorLightGreen → String
The name of the color, Light Green.
no setteroverride
colorLightPink → String
The name of the color, Light Pink.
no setteroverride
colorLightSalmon → String
The name of the color, Light Salmon.
no setteroverride
colorLightSeaGreen → String
The name of the color, Light Sea Green.
no setteroverride
colorLightSkyBlue → String
The name of the color, Light Sky Blue.
no setteroverride
colorLightSlateGray → String
The name of the color, Light Slate Gray.
no setteroverride
colorLightSteelBlue → String
The name of the color, Light Steel Blue.
no setteroverride
colorLightYellow → String
The name of the color, Light Yellow.
no setteroverride
colorLime → String
The name of the color, Lime.
no setteroverride
colorLimeGreen → String
The name of the color, Lime Green.
no setteroverride
colorLinen → String
The name of the color, Linen.
no setteroverride
colorMagenta → String
The name of the color, Magenta.
no setteroverride
colorMaroon → String
The name of the color, Maroon.
no setteroverride
colorMediumAquamarine → String
The name of the color, Medium Aquamarine.
no setteroverride
colorMediumBlue → String
The name of the color, Medium Blue.
no setteroverride
colorMediumOrchid → String
The name of the color, Medium Orchid.
no setteroverride
colorMediumPurple → String
The name of the color, Medium Purple.
no setteroverride
colorMediumSeaGreen → String
The name of the color, Medium Sea Green.
no setteroverride
colorMediumSlateBlue → String
The name of the color, Medium Slate Blue.
no setteroverride
colorMediumSpringGreen → String
The name of the color, Medium Spring Green.
no setteroverride
colorMediumTurquoise → String
The name of the color, Medium Turquoise.
no setteroverride
colorMediumVioletRed → String
The name of the color, Medium Violet Red.
no setteroverride
colorMidnightBlue → String
The name of the color, Midnight Blue.
no setteroverride
colorMintCream → String
The name of the color, Mint Cream.
no setteroverride
colorMistyRose → String
The name of the color, Misty Rose.
no setteroverride
colorMoccasin → String
The name of the color, Moccasin.
no setteroverride
colorNavajoWhite → String
The name of the color, Navajo White.
no setteroverride
colorNavy → String
The name of the color, Navy.
no setteroverride
colorOldLace → String
The name of the color, Old Lace.
no setteroverride
colorOlive → String
The name of the color, Olive.
no setteroverride
colorOliveDrab → String
The name of the color, Olive Drab.
no setteroverride
colorOrange → String
The name of the color, Orange.
no setteroverride
colorOrangeRed → String
The name of the color, Orange Red.
no setteroverride
colorOrchid → String
The name of the color, Orchid.
no setteroverride
colorPaleGoldenrod → String
The name of the color, Pale Goldenrod.
no setteroverride
colorPaleGreen → String
The name of the color, Pale Green.
no setteroverride
colorPaleTurquoise → String
The name of the color, Pale Turquoise.
no setteroverride
colorPaleVioletRed → String
The name of the color, Pale Violet Red.
no setteroverride
colorPapayaWhip → String
The name of the color, Papaya Whip.
no setteroverride
colorPeachPuff → String
The name of the color, Peach Puff.
no setteroverride
colorPeru → String
The name of the color, Peru.
no setteroverride
colorPink → String
The name of the color, Pink.
no setteroverride
colorPlum → String
The name of the color, Plum.
no setteroverride
colorPowderBlue → String
The name of the color, Powder Blue.
no setteroverride
colorPurple → String
The name of the color, Purple.
no setteroverride
colorRed → String
The name of the color, Red.
no setteroverride
colorRosyBrown → String
The name of the color, Rosy Brown.
no setteroverride
colorRoyalBlue → String
The name of the color, Royal Blue.
no setteroverride
colorSaddleBrown → String
The name of the color, Saddle Brown.
no setteroverride
colorSalmon → String
The name of the color, Salmon.
no setteroverride
colorSandyBrown → String
The name of the color, Sandy Brown.
no setteroverride
colorSeaGreen → String
The name of the color, Sea Green.
no setteroverride
colorSeaShell → String
The name of the color, Sea Shell.
no setteroverride
colorSienna → String
The name of the color, Sienna.
no setteroverride
colorSilver → String
The name of the color, Silver.
no setteroverride
colorSkyBlue → String
The name of the color, Sky Blue.
no setteroverride
colorSlateBlue → String
The name of the color, Slate Blue.
no setteroverride
colorSlateGray → String
The name of the color, Slate Gray.
no setteroverride
colorSnow → String
The name of the color, Snow.
no setteroverride
colorSpringGreen → String
The name of the color, Spring Green.
no setteroverride
colorSteelBlue → String
The name of the color, Steel Blue.
no setteroverride
colorTan → String
The name of the color, Tan.
no setteroverride
colorTeal → String
The name of the color, Teal.
no setteroverride
colorThistle → String
The name of the color, Thistle.
no setteroverride
colorTomato → String
The name of the color, Tomato.
no setteroverride
colorTurquoise → String
The name of the color, Turquoise.
no setteroverride
colorViolet → String
The name of the color, Violet.
no setteroverride
colorWheat → String
The name of the color, Wheat.
no setteroverride
colorWhite → String
The name of the color, White.
no setteroverride
colorWhiteSmoke → String
The name of the color, White Smoke.
no setteroverride
colorYellow → String
The name of the color, Yellow.
no setteroverride
colorYellowGreen → String
The name of the color, Yellow Green.
no setteroverride
copyActionLabel → String
The label for the copy action on the text selection controls.
no setteroverride
copyActionTooltip → String
The tooltip for the copy action on the text selection controls.
no setteroverride
copyShortcut → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

The copy shortcut label used by text selection controls.
no setter
cutActionLabel → String
The label for the cut action on the text selection controls.
no setteroverride
cutActionTooltip → String
The tooltip for the cut action on the text selection controls.
no setteroverride
cutShortcut → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

The cut shortcut label used by text selection controls.
no setter
day → String
The text used by DatePicker for the day field
no setteroverride
dialogLabel → String
The dialog label.
no setteroverride
greenLabel → String
Label for green color component in color picker
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hour → String
The text used by TimePicker for the hour field.
no setteroverride
hueLabel → String
Label for hue component in color picker
no setteroverride
lessText → String
Text for collapsing color picker options
no setteroverride
localeName → String
finalinherited
minimizeWindowTooltip → String
The tooltip used by the "Minimize" button on desktop windows.
no setteroverride
minute → String
The text used by TimePicker for the minute field.
no setteroverride
modalBarrierDismissLabel → String
Label read out by accessibility tools (TalkBack or VoiceOver) for a modal barrier to indicate that a tap dismisses the barrier. A modal barrier can for example be found behind an alert or popup to block user interaction with elements behind it.
no setteroverride
month → String
The text used by DatePicker for the month field
no setteroverride
moreText → String
Text for expanding color picker options
no setteroverride
newTabLabel → String
The label used by TabView's new button.
no setteroverride
noResultsFoundLabel → String
The label used by AutoSuggestBox when the results can't be found.
no setteroverride
opacityLabel → String
Label for opacity component in color picker
no setteroverride
openNavigationTooltip → String
The tooltip for the toogle navigation button.
no setteroverride
pasteActionLabel → String
The label for the paste button on the text selection controls.
no setteroverride
pasteActionTooltip → String
The tooltip for the paste action on the text selection controls.
no setteroverride
pasteShortcut → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

The paste shortcut label used by text selection controls.
no setter
pickADate → String
The text used by CalendarDatePicker to prompt the user to pick a date.
no setteroverride
pm → String
The text used by TimePicker for the PM field.
no setteroverride
redLabel → String
Label for red color component in color picker
no setteroverride
restoreWindowTooltip → String
The tooltip used by the "Restore" button on desktop windows.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturationLabel → String
Label for saturation component in color picker
no setteroverride
scrollTabBackwardLabel → String
The label used by TabView's scroll backward button.
no setteroverride
scrollTabForwardLabel → String
The label used by TabView's scroll forward button.
no setteroverride
searchLabel → String
Label for "search" text fields.
no setteroverride
seeLess → String
The text used by CommandBar to show less items.
no setteroverride
seeMore → String
The text used by CommandBar to show more items.
no setteroverride
selectAllActionLabel → String
The label for the select all button on the text selection controls.
no setteroverride
selectAllActionTooltip → String
The tooltip for the select all action on the text selection controls.
no setteroverride
selectAllShortcut → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

The select all shortcut label used by text selection controls.
no setter
undoActionLabel → String
The label for the undo button on the text selection controls.
no setteroverride
undoActionTooltip → String
The tooltip for the undo action on the text selection controls.
no setteroverride
undoShortcut → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

The select all shortcut label used by text selection controls.
no setter
valueLabel → String
Label for value component in color picker
no setteroverride
year → String
The text used by DatePicker for the year field
no setteroverride

Methods

alphaSliderTooltip(int value) → String
No description provided for @alphaSliderTooltip.
override
getColorDisplayName(String colorKey) → String

Available on FluentLocalizations, provided by the FluentLocalizationsExtension extension

Returns DisplayName of the color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueSliderTooltip(int value, String colorName) → String
No description provided for @valueSliderTooltip.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited