ButtonThemeData class

Mixed-in types
Annotations

Constructors

ButtonThemeData({ButtonState<Decoration?>? decoration, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, double? scaleFactor, ButtonState<MouseCursor>? cursor, ButtonState<TextStyle>? textStyle, Duration? animationDuration, Curve? animationCurve})
const
ButtonThemeData.standard(ThemeData style)
factory

Properties

animationCurve → Curve?
final
animationDuration → Duration?
final
cursor → ButtonState<MouseCursor>?
final
decoration → ButtonState<Decoration?>?
final
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsetsGeometry?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor → double?
final
textStyle → ButtonState<TextStyle>?
final

Methods

copyWith(ButtonThemeData? style) → ButtonThemeData
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited