FlyoutAutoConfiguration class
Configuration for automatic flyout placement.
When using FlyoutPlacementMode.auto, this configuration determines how the flyout position is calculated based on available space.
Constructors
- FlyoutAutoConfiguration({required FlyoutPlacementMode preferredMode, double? autoAvailableSpace, bool? horizontal})
- Creates the configuration for flyout auto mode.
Properties
- autoAvailableSpace → double?
-
The amount of necessary available space.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontal → bool
-
Whether the flyout should be displayed horizontally.
final
- preferredMode → FlyoutPlacementMode
-
The preferred placement mode when auto-positioning.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited