FocusThemeData class

Mixed-in types

Constructors

FocusThemeData({BorderRadius? borderRadius, BorderSide? primaryBorder, BorderSide? secondaryBorder, Color? glowColor, double? glowFactor, bool? renderOutside, Duration? animationDuration, Curve? animationCurve})
const
FocusThemeData.standard({required Color primaryBorderColor, required Color secondaryBorderColor, required Color glowColor, required Duration animationDuration, required Curve animationCurve})
factory

Properties

animationCurve → Curve?
final
animationDuration → Duration?
final
borderRadius → BorderRadius?
final
glowColor → Color?
final
glowFactor → double?
final
hashCode → int
The hash code for this object.
no setterinherited
primaryBorder → BorderSide?
final
renderOutside → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryBorder → BorderSide?
final

Methods

buildPrimaryDecoration(bool focused) → BoxDecoration
buildSecondaryDecoration(bool focused) → BoxDecoration
copyWith(FocusThemeData? other) → FocusThemeData
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → FocusThemeData