InfoBarThemeData class
Theme data for InfoBar widgets.
This class defines the visual appearance of info bars, including their decoration, icons, and styling for different severity levels.
- Mixed-in types
Constructors
-
InfoBarThemeData({InfoBarSeverityCheck<
Decoration?> ? decoration, InfoBarSeverityCheck<IconData> ? icon, InfoBarSeverityCheck<Color?> ? iconColor, ButtonStyle? closeButtonStyle, IconData? closeIcon, double? closeIconSize, ButtonStyle? actionStyle, EdgeInsetsGeometry? padding}) -
Creates a theme data for InfoBar widgets.
const
- InfoBarThemeData.standard(FluentThemeData theme)
-
Creates a standard theme data for InfoBar widgets.
factory
Properties
- actionStyle → ButtonStyle?
-
The style for the action button.
final
- closeButtonStyle → ButtonStyle?
-
The style for the close button.
final
- closeIcon → IconData?
-
The icon to display for the close button.
final
- closeIconSize → double?
-
The size of the close icon.
final
-
decoration
→ InfoBarSeverityCheck<
Decoration?> ? -
Returns the decoration based on the severity level.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
icon
→ InfoBarSeverityCheck<
IconData> ? -
Returns the icon to display based on the severity level.
final
-
iconColor
→ InfoBarSeverityCheck<
Color?> ? -
Returns the icon color based on the severity level.
final
- padding → EdgeInsetsGeometry?
-
The padding around the info bar content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
merge(
InfoBarThemeData? style) → InfoBarThemeData - Merges this InfoBarThemeData with another, with the other taking precedence.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
InfoBarThemeData? a, InfoBarThemeData? b, double t) → InfoBarThemeData - Lerps between two InfoBarThemeData objects.