NavigationPaneWidgetData class
Data passed to custom navigation pane widgets.
Constructors
-
Creates navigation pane widget data.
const
Properties
- content → Widget
-
The main content of the navigation view.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listKey
→ GlobalKey<
State< StatefulWidget> > -
The key for the list of items.
final
- pane → NavigationPane
-
The navigation pane configuration.
final
- paneKey → Key
-
The key for the pane.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController
-
The scroll controller for the pane.
final
- titleBar → Widget?
-
The app bar widget.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited