WidgetStateExtension extension
Extension methods for Set<WidgetState> to easily check interaction states.
- on
Properties
- isDisabled → bool
-
Available on Set<
Checks whether the widget is disabled.WidgetState> , provided by the WidgetStateExtension extensionno setter - isFocused → bool
-
Available on Set<
Checks whether the widget is focused.WidgetState> , provided by the WidgetStateExtension extensionno setter - isHovered → bool
-
Available on Set<
Checks whether the widget is hovered.WidgetState> , provided by the WidgetStateExtension extensionno setter - isNone → bool
-
Available on Set<
Checks whether the widget is in its default state.WidgetState> , provided by the WidgetStateExtension extensionno setter - isPressed → bool
-
Available on Set<
Checks whether the widget is pressed.WidgetState> , provided by the WidgetStateExtension extensionno setter
Methods
-
isAllOf(
Iterable< WidgetState> states) → bool -
Available on Set<
Checks whether the widget is in all of the provided states.WidgetState> , provided by the WidgetStateExtension extension -
isAnyOf(
Iterable< WidgetState> states) → bool -
Available on Set<
Checks whether the widget is in any of the provided states.WidgetState> , provided by the WidgetStateExtension extension
Static Methods
-
forStates<
T> (Set< WidgetState> states, {required T disabled, required T none, T? pressed, T? hovering, T? focused}) → T -
Available on Set<
Returns the value for the provided states.WidgetState> , provided by the WidgetStateExtension extension